@@ -1,15 +1,14 @@
 package Hailo::Role::Tokenizer;
 BEGIN {
-  $Hailo::Role::Tokenizer::VERSION = '0.41';
+  $Hailo::Role::Tokenizer::VERSION = '0.42';
 }
 
 use 5.010;
 use Any::Moose '::Role';
-use Any::Moose 'X::Types::'.any_moose() => [qw/HashRef Int/];
 use namespace::clean -except => 'meta';
 
 has spacing => (
-    isa     => HashRef[Int],
+    isa     => 'HashRef[Int]',
     is      => 'rw',
     default => sub { {
         normal  => 0,
