@@ -1,11 +1,10 @@
 package Hailo::Storage;
 BEGIN {
-  $Hailo::Storage::VERSION = '0.41';
+  $Hailo::Storage::VERSION = '0.42';
 }
 
 use 5.010;
 use Any::Moose;
-use Any::Moose 'X::Types::'.any_moose() => [qw<ArrayRef HashRef Int Str Bool>];
 BEGIN {
     return unless Any::Moose::moose_is_preferred();
     require MooseX::StrictConstructor;
@@ -15,14 +14,14 @@ use DBI;
 use Hailo::Storage::Schema;
 
 has dbd => (
-    isa           => Str,
+    isa           => 'Str',
     is            => 'ro',
     lazy_build    => 1,
     documentation => "The DBD::* driver we're using",
 );
 
 has dbd_options => (
-    isa           => HashRef,
+    isa           => 'HashRef',
     is            => 'ro',
     lazy_build    => 1,
     documentation => 'Options passed as the last argument to DBI->connect()',
@@ -50,7 +49,7 @@ sub _build_dbh {
 };
 
 has dbi_options => (
-    isa           => ArrayRef,
+    isa           => 'ArrayRef',
     is            => 'ro',
     auto_deref    => 1,
     lazy_build    => 1,
@@ -74,14 +73,14 @@ sub _build_dbi_options {
 }
 
 has _engaged => (
-    isa           => Bool,
+    isa           => 'Bool',
     is            => 'rw',
     default       => 0,
     documentation => 'Have we done setup work to get this database going?',
 );
 
 has sth => (
-    isa        => HashRef,
+    isa        => 'HashRef',
     is         => 'ro',
     lazy_build => 1,
     documentation => 'A HashRef of prepared DBI statement handles',
@@ -93,7 +92,7 @@ sub _build_sth {
 }
 
 has _boundary_token_id => (
-    isa => Int,
+    isa => 'Int',
     is  => 'rw',
 );
 
@@ -143,7 +142,7 @@ DIE
         my $id = $self->sth->{last_token_rowid}->fetchrow_array();
         $self->_boundary_token_id($id);
     }
-    
+
     $self->_engaged(1);
 
     return;
